@@ -573,7 +573,8 @@ def train_loop(
         # manager_dir does not point to the model directory when we are running
         # in a worker.
         latest_checkpoint = tf.train.latest_checkpoint(model_dir)
-        ckpt.restore(latest_checkpoint)
+        ckpt.restore(latest_checkpoint).expect_partial()
+
 
         def train_step_fn(features, labels):
           """Single train step."""
